<!--
 * @Descripttion:
 * @version:
 * @Author: kBank
 * @Date: 2022-10-24 15:45:01
-->
<template>
  <div class="page">
    <topBar
      v-if="topList.length > 0"
      :top-list="topList"
      :moren="moren"
    />
    <div class="main">
      <el-form
        ref="select"
        :model="select"
        style="padding: 0 10px 0 0"
        label-width="80px"
      >
        <el-row>
          <!-- 一层 -->
          <!-- <el-col :span="4">
            <el-form-item :label="'收益展示'">
              <el-select clearable
                         :placeholder="'请选择'"
                         v-model="select.websiteType">
                <el-option v-for="item in acList"
                           :key="item.value"
                           :label="item.label"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-form-item :label="'币种展示'">
              <el-select clearable
                         :placeholder="'请选择'"
                         v-model="select.websiteType">
                <el-option v-for="item in acList"
                           :key="item.value"
                           :label="item.label"
                           :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col> -->

          <el-col :span="8">
            <el-form-item :label="'统计时间'">
              <el-date-picker
                v-model="creationTime"
                value-format="yyyy-MM-dd"
                type="daterange"
                :range-separator="'至'"
                :start-placeholder="'开始日期'"
                :end-placeholder="'结束日期'"
                @change="changeTime"
              />
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item label="系统编号">
              <el-select v-model="select.pkVertex">
                <el-option
                  v-for="item in verList"
                  :key="item.pkVertex"
                  :label="`${item.memberCode} (${item.memberName})`"
                  :value="item.pkVertex"
                />
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4" style="margin-left: 10px">
            <el-button type="primary" @click="getDataList">
              {{ '搜索' }}</el-button>
            <el-button type="primary" @click="reset">
              {{ '重置' }}</el-button>
            <el-button v-hasButtons="['TopPerformanceTotal']" type="primary" @click="getNewData"> 统计</el-button>
          </el-col>
        </el-row>
        <el-row />
      </el-form>
      <div class="maintop">
        <div class="mainbtn">
          <el-button
            v-hasButtons="['TopPerformanceExport']"
            size="small"
            class="thebtn2"
            @click="handleExport"
          >
            {{ '导出' }}</el-button>
        </div>
      </div>
      <div class="maintable">
        <!-- <div class="itemTrading"> -->
        <el-table
          ref="mainTable"
          v-loading="loading"
          :data="tableData"
          height="700px"
          :header-cell-style="{ background: '#EEEEEE' }"
          :summary-method="getSummaries"
          show-summary
          :row-class-name="tableRowClassName"
          @selection-change="handleSelectionChange"
        >
          <el-table-column type="selection" width="60" />
          <el-table-column
            v-for="(item, index) in menuList"
            v-if="item.id != 0"
            :key="item.id"
            align="center"
            min-width="140"
            :prop="item.prop"
            :label="item.text"
          >
            <template slot-scope="scope">
              <div v-if="index > 4">
                {{ scope.row[item.prop] | numberToCurrency }}
              </div>
              <div v-if="index <= 4">{{ scope.row[item.prop] }}</div>
            </template>
          </el-table-column>
        </el-table>
        <!-- </div> -->
      </div>
    </div>
    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getDataList"
    />
  </div>
</template>

<script>
import topBar from '@/components/topBar'
import * as api from '@/api/settle.js'
import { classifyUpdate, classifySave } from '@/api/product'
import { getRouters } from '@/api/settle.js'
import { isOther, numberToCurrencyNo } from '@/utils/numberToCurrency'
export default {
  name: 'Bzpz',
  components: {
    topBar
  },
  filters: {
    isAgree(val) {
      if (!val) {
        return '允许'
      } else {
        return '禁止'
      }
    }
  },
  data() {
    return {
      loading: false,
      typeList: [
        {
          value: 0,
          label: '前台'
        },
        {
          value: 1,
          label: '后台'
        }
      ],
      digList: [
        {
          value: 0,
          label: '允许'
        },
        {
          value: 1,
          label: '禁止'
        }
      ],
      menuList: [
        {
          id: 0,
          text: '全选',
          checked: false
        },
        {
          id: 1,
          text: '系统编号',
          checked: true,
          prop: 'memberCode'
        },
        {
          id: 31,
          text: '系统名称',
          checked: true,
          prop: 'memberName'
        },
        {
          id: 27,
          text: '统计时间',
          checked: false,
          prop: 'creationTime'
        },
        {
          id: 2,
          text: '隶属团队',
          checked: true,
          prop: 'teamName'
        },
        {
          id: 3,
          text: `${'注册专区'}`,
          checked: true,
          prop: 'mainRegAmount',
          total: 'mainRegAmountSum'
        },
        {
          id: 4,
          text: `${'升级专区'}`,
          checked: true,
          prop: 'mainUpAmount',
          total: 'mainUpAmountSum'
        },
        {
          id: 7,
          text: `${'首购金额'}`,
          checked: true,
          prop: 'firstPurchaseAll',
          total: 'firstPurchaseAllSum'
        },
        {
          id: 8,
          text: `${'直推收益'}`,
          checked: true,
          prop: 'introduceBonus',
          total: 'introduceBonusSum'
        },
        {
          id: 9,
          text: `${'拓展收益'}`,
          checked: true,
          prop: 'orgBonus',
          total: 'orgBonusSum'
        },
        {
          id: 10,
          text: `${'辅导收益'}`,
          checked: true,
          prop: 'leaderBonus',
          total: 'leaderBonusSum'
        },
        {
          id: 12,
          text: `${'服务补贴'}`,
          checked: true,
          prop: 'serviceBonus',
          total: 'serviceBonusSum'
        },
        {
          id: 16,
          text: `${'复购专区'}`,
          checked: true,
          prop: 'mainRepurAmount',
          total: 'mainRepurAmountSum'
        },
        {
          id: 18,
          text: `${'复购金额'}`,
          checked: false,
          prop: 'repurchaseAllAmount',
          total: 'repurchaseAllAmountSum'
        },
        {
          id: 19,
          text: `${'复购级差收益'}`,
          checked: false,
          prop: 'repurRangeBonus',
          total: 'repurRangeBonusSum'
        },
        {
          id: 20,
          text: `${'复购拓展收益'}`,
          checked: false,
          prop: 'repurOrgBonus',
          total: 'repurOrgBonusSum'
        },
        {
          id: 'repurLeaderBonus',
          text: `${'复购辅导收益'}`,
          checked: false,
          prop: 'repurLeaderBonus',
          total: 'repurLeaderBonusSum'
        },
        {
          id: 21,
          text: `${'首购拨出金额'}`,
          checked: false,
          prop: 'mainBonus',
          total: 'mainBonusSum'
        },
        {
          id: 22,
          text: '首购拨出比例' + '(%)',
          checked: false,
          prop: 'mainBonusRate',
          total: 'mainBonusRateSum'
        },
        {
          id: 23,
          text: `${'复购拨出金额'}`,
          checked: false,
          prop: 'repurBonus',
          total: 'repurBonusSum'
        },
        {
          id: 24,
          text: '复购拨出比例' + '(%)',
          checked: false,
          prop: 'repurBonusRate',
          total: 'repurBonusRateSum'
        },
        {
          id: 25,
          text: `${'总拨出金额'}`,
          checked: false,
          prop: 'totalBonus',
          total: 'totalBonusSum'
        },
        {
          id: 26,
          text: '总拨出比例' + '(%)',
          checked: false,
          prop: 'totalBonusRate',
          total: 'totalBonusRateSum'
        }

        // {
        //   id: 28,
        //   text: '截止日期',
        //   checked: false,
        //   prop: 'endDate',
        // },
      ],
      creationTime: [],
      creationTime1: [],
      select: {
        pkVertexList: [],
        pkMemberTeamList: []
      },
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 50
      },
      addOrEdit: '',
      total: 0,
      dialogVisible: false,
      tableData: [],
      moren: '/settlementCenter/topPerformance',
      topList: [
        {
          name: '零线系统拨比统计',
          path: '/settlementCenter/topPerformance',
          url: 'topPerformance',
          changed: false
        }

      ],
      form: {},
      verList: [],
      memberList: [],
      acList: [],
      tableList: {},
      props: {
        multiple: true,
        expandTrigger: 'hover',
        value: 'pkId',
        label: 'vertexName',
        children: 'childList'
      }
    }
  },
  mounted() {
    // 获取下拉
    this.getData()
    // 获取列表
    this.getDataList()
    // this.getUserRoute();
  },
  methods: {
    getPkBdVertexStr(e) {
      const arr = e.map((item) => item[1])
      const pkBdVertexStr = arr.join(',')
      this.$set(this.select, 'pkBdVertexStr', pkBdVertexStr)
    },
    // getpkVertex() {
    //   let pkBdVertexStr = this.select.pkVertexList.join(',')
    //   this.$set(this.select, 'pkBdVertexStr', pkBdVertexStr)
    // },
    // getTeam() {
    //   let pkTeamCodeStr = this.select.pkMemberTeamList.join(',')
    //   this.$set(this.select, 'pkTeamCodeStr', pkTeamCodeStr)
    // },
    getTotal() {
      api
        .topSubtotal(Object.assign({}, this.queryParams, this.select))
        .then((res) => {
          if (res.code == 200) {
            this.tableList = res.data
          }
        })
    },
    getSummaries(param) {
      const arr = []
      this.menuList.forEach((item) => {
        for (var i in this.tableList) {
          if (i == item.total) {
            arr.push(numberToCurrencyNo(this.tableList[i]))
          }
        }
      })
      arr.unshift('合计', '', '', '', '')
      arr.push('')
      this.$nextTick(() => {
        this.$refs.mainTable.doLayout()
      })
      return arr
      // return []
    },
    getUserRoute() {
      getRouters().then((res) => {
        res.data.forEach((item) => {
          this.topList.forEach((items) => {
            if (item.routeName == items.url) {
              items.changed = true
            }
          })
        })
      })
    },
    reset() {
      this.select = {
        pkVertexList: [],
        pkMemberTeamList: [],
        pkTeamCodeStr: '',
        pkBdVertexStr: ''
      }
      this.creationTime = []
    },
    getData() {
      api.accountList().then((res) => {
        this.acList = res.data
      })
      // api.vertexList().then((res) => {
      //   this.verList = res.data
      // })
      // api.memberTeam().then((res) => {
      //   this.memberList = res.rows
      // })
      api.topVertexList().then((res) => {
        this.verList = res.rows
      })
    },
    changeTime(val) {
      this.select.startDate = val ? val[0] : ''
      this.select.endDate = val ? val[1] : ''
    },
    changeTime1(val) {
      this.select.startEffectDate = val ? val[0] : ''
      this.select.endEffectDate = val ? val[1] : ''
    },
    getNewData() {
      this.loading = true
      api
        .topBonusListHistory(Object.assign({}, this.queryParams, this.select))
        .then((res) => {
          this.getDataList()
        })
    },
    getDataList() {
      api
        .topBonusList(Object.assign({}, this.queryParams, this.select))
        .then((res) => {
          this.loading = false
          if (res.code == 200) {
            this.tableData = res.rows
            this.total = res.total
            this.getTotal()
          }
        })
    },
    handleSelectionChange(val) {},
    /** 导出按钮操作 */
    handleExport() {
      this.$confirm('是否确认导出所有数据项?', '警告', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then((_) => {
        this.download(
          '/member/manage/bonus-vertex-statis/export',
          Object.assign({}, this.queryParams, this.select),
          `零线系统拨比统计-${new Date().getTime()}.xlsx`
        )
      })
    },
    tableRowClassName({ row, rowIndex }) {
      if (rowIndex % 2 == 1) {
        return 'warning-row'
      } else if (rowIndex % 2 == 0) {
        return 'success-row'
      }
      return ''
    }
  }
}
</script>
<style scoped lang="scss">
::v-deep .el-table .warning-row {
  background: #f9f9f9;
}

::v-deep .el-table .success-row {
  background: #ffffff;
}
::v-deep .el-table thead {
  color: #000000;
}
::v-deep .el-select {
  width: 100%;
}
.uploadIcon ::v-deep .el-upload--picture-card {
  display: none !important; /* 上传按钮隐藏 */
}
.page {
  padding: 20px;
  background: #f9f9f9;
  font-size: 14px;
  .main {
    background: #ffffff;
    border-radius: 8px;
    box-shadow: 0px 2px 20px 0px rgba(238, 238, 238, 0.5);
    display: flex;
    flex-direction: column;
    .maintop {
      display: flex;
      // padding: 0 10px;
      justify-content: space-between;
      align-items: center;
      .mainbtn {
        .thebtn1 {
          background: #3181e5;
          color: #ffffff;
        }
        .thebtn2 {
          background: #ffad41;
          color: #ffffff;
        }
      }
      .maintitle {
        font-size: 10px;
        font-family: MicrosoftYaHei;
        color: #999999;
      }
    }
    .maintable {
      flex: 1;
    }
  }
  .tem {
    display: flex;
    align-items: center;
    justify-content: center;
    img {
      width: 28px;
      height: 20px;
      margin-right: 3px;
    }
  }
  .isRed {
    color: #ed1d25;
  }
  .isGreen {
    color: #1ab62b;
  }
  .bgImg {
    width: 48px;
    height: 48px;
  }
}
.openClose {
  text-align: right;
  margin-right: 10px;
  color: #3181e5;
}
.kuang {
  padding: 5px 20px;
  background: rgba(255, 255, 255, 0);
  border-radius: 4px;
  border: 1px solid #cccccc;
}
.heji {
  margin-top: 10px;
  .dis {
    display: flex;
    justify-content: right;
    padding: 5px 10px;
    font-size: 14px;
    color: #333333;
    :nth-child(1) {
      font-size: 14px;
      font-weight: bold;
      color: #333333;
      margin-right: 20px;
    }
  }
}
::v-deep .el-date-editor--daterange,
.el-cascader {
  width: 100%;
}
::v-deep .el-input__suffix {
  top: -3px;
}
</style>
